from . import itkimageprocessing

def illumination_correction(data_container_array, montage_selection = None, data_containers = None, cell_attribute_matrix_name = None, image_data_array_name = None, corrected_image_data_array_name = None, export_corrected_images = None, output_path = None, file_extension = None, background_data_container_path = None, background_cell_attribute_matrix_path = None, background_image_array_path = None, low_threshold = None, high_threshold = None, apply_correction = None, apply_median_filter = None, median_radius = None, observer = None) -> int:
  """Pythonic interface to IlluminationCorrection Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    montage_selection (MontageSelection): Sets the "MontageSelection" filter property
    data_containers (QStringList): Sets the "DataContainers" filter property
    cell_attribute_matrix_name (QString): Sets the "CellAttributeMatrixName" filter property
    image_data_array_name (QString): Sets the "ImageDataArrayName" filter property
    corrected_image_data_array_name (QString): Sets the "CorrectedImageDataArrayName" filter property
    export_corrected_images (bool): Sets the "ExportCorrectedImages" filter property
    output_path (QString): Sets the "OutputPath" filter property
    file_extension (QString): Sets the "FileExtension" filter property
    background_data_container_path (DataArrayPath): Sets the "BackgroundDataContainerPath" filter property
    background_cell_attribute_matrix_path (DataArrayPath): Sets the "BackgroundCellAttributeMatrixPath" filter property
    background_image_array_path (DataArrayPath): Sets the "BackgroundImageArrayPath" filter property
    low_threshold (uint32_t): Sets the "LowThreshold" filter property
    high_threshold (uint32_t): Sets the "HighThreshold" filter property
    apply_correction (bool): Sets the "ApplyCorrection" filter property
    apply_median_filter (bool): Sets the "ApplyMedianFilter" filter property
    median_radius (FloatVec3Type): Sets the "MedianRadius" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.IlluminationCorrection()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if montage_selection is not None:
    filter.MontageSelection = montage_selection
  if data_containers is not None:
    filter.DataContainers = data_containers
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if image_data_array_name is not None:
    filter.ImageDataArrayName = image_data_array_name
  if corrected_image_data_array_name is not None:
    filter.CorrectedImageDataArrayName = corrected_image_data_array_name
  if export_corrected_images is not None:
    filter.ExportCorrectedImages = export_corrected_images
  if output_path is not None:
    filter.OutputPath = output_path
  if file_extension is not None:
    filter.FileExtension = file_extension
  if background_data_container_path is not None:
    filter.BackgroundDataContainerPath = background_data_container_path
  if background_cell_attribute_matrix_path is not None:
    filter.BackgroundCellAttributeMatrixPath = background_cell_attribute_matrix_path
  if background_image_array_path is not None:
    filter.BackgroundImageArrayPath = background_image_array_path
  if low_threshold is not None:
    filter.LowThreshold = low_threshold
  if high_threshold is not None:
    filter.HighThreshold = high_threshold
  if apply_correction is not None:
    filter.ApplyCorrection = apply_correction
  if apply_median_filter is not None:
    filter.ApplyMedianFilter = apply_median_filter
  if median_radius is not None:
    filter.MedianRadius = median_radius
  filter.execute()
  return filter.ErrorCode

def import_axio_vision_v4_montage(data_container_array, montage_name = None, input_file = None, data_container_path = None, cell_attribute_matrix_name = None, image_data_array_name = None, convert_to_gray_scale = None, color_weights = None, change_origin = None, origin = None, change_spacing = None, spacing = None, row_count = None, column_count = None, import_all_meta_data = None, meta_data_attribute_matrix_name = None, column_montage_limits = None, row_montage_limits = None, observer = None) -> int:
  """Pythonic interface to ImportAxioVisionV4Montage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    montage_name (QString): Sets the "MontageName" filter property
    input_file (QString): Sets the "InputFile" filter property
    data_container_path (DataArrayPath): Sets the "DataContainerPath" filter property
    cell_attribute_matrix_name (QString): Sets the "CellAttributeMatrixName" filter property
    image_data_array_name (QString): Sets the "ImageDataArrayName" filter property
    convert_to_gray_scale (bool): Sets the "ConvertToGrayScale" filter property
    color_weights (FloatVec3Type): Sets the "ColorWeights" filter property
    change_origin (bool): Sets the "ChangeOrigin" filter property
    origin (FloatVec3Type): Sets the "Origin" filter property
    change_spacing (bool): Sets the "ChangeSpacing" filter property
    spacing (FloatVec3Type): Sets the "Spacing" filter property
    row_count (int32_t): Sets the "RowCount" filter property
    column_count (int32_t): Sets the "ColumnCount" filter property
    import_all_meta_data (bool): Sets the "ImportAllMetaData" filter property
    meta_data_attribute_matrix_name (QString): Sets the "MetaDataAttributeMatrixName" filter property
    column_montage_limits (IntVec2Type): Sets the "ColumnMontageLimits" filter property
    row_montage_limits (IntVec2Type): Sets the "RowMontageLimits" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ImportAxioVisionV4Montage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if montage_name is not None:
    filter.MontageName = montage_name
  if input_file is not None:
    filter.InputFile = input_file
  if data_container_path is not None:
    filter.DataContainerPath = data_container_path
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if image_data_array_name is not None:
    filter.ImageDataArrayName = image_data_array_name
  if convert_to_gray_scale is not None:
    filter.ConvertToGrayScale = convert_to_gray_scale
  if color_weights is not None:
    filter.ColorWeights = color_weights
  if change_origin is not None:
    filter.ChangeOrigin = change_origin
  if origin is not None:
    filter.Origin = origin
  if change_spacing is not None:
    filter.ChangeSpacing = change_spacing
  if spacing is not None:
    filter.Spacing = spacing
  if row_count is not None:
    filter.RowCount = row_count
  if column_count is not None:
    filter.ColumnCount = column_count
  if import_all_meta_data is not None:
    filter.ImportAllMetaData = import_all_meta_data
  if meta_data_attribute_matrix_name is not None:
    filter.MetaDataAttributeMatrixName = meta_data_attribute_matrix_name
  if column_montage_limits is not None:
    filter.ColumnMontageLimits = column_montage_limits
  if row_montage_limits is not None:
    filter.RowMontageLimits = row_montage_limits
  filter.execute()
  return filter.ErrorCode

def axio_vision_v4_to_tile_configuration(data_container_array, input_file = None, output_file = None, observer = None) -> int:
  """Pythonic interface to AxioVisionV4ToTileConfiguration Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    input_file (QString): Sets the "InputFile" filter property
    output_file (QString): Sets the "OutputFile" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.AxioVisionV4ToTileConfiguration()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if input_file is not None:
    filter.InputFile = input_file
  if output_file is not None:
    filter.OutputFile = output_file
  filter.execute()
  return filter.ErrorCode

def import_zen_info_montage(data_container_array, montage_name = None, length_unit = None, input_file = None, data_container_path = None, cell_attribute_matrix_name = None, image_data_array_name = None, convert_to_gray_scale = None, color_weights = None, change_origin = None, origin = None, change_spacing = None, spacing = None, row_count = None, column_count = None, column_montage_limits = None, row_montage_limits = None, observer = None) -> int:
  """Pythonic interface to ImportZenInfoMontage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    montage_name (QString): Sets the "MontageName" filter property
    length_unit (int32_t): Sets the "LengthUnit" filter property
    input_file (QString): Sets the "InputFile" filter property
    data_container_path (DataArrayPath): Sets the "DataContainerPath" filter property
    cell_attribute_matrix_name (QString): Sets the "CellAttributeMatrixName" filter property
    image_data_array_name (QString): Sets the "ImageDataArrayName" filter property
    convert_to_gray_scale (bool): Sets the "ConvertToGrayScale" filter property
    color_weights (FloatVec3Type): Sets the "ColorWeights" filter property
    change_origin (bool): Sets the "ChangeOrigin" filter property
    origin (FloatVec3Type): Sets the "Origin" filter property
    change_spacing (bool): Sets the "ChangeSpacing" filter property
    spacing (FloatVec3Type): Sets the "Spacing" filter property
    row_count (int32_t): Sets the "RowCount" filter property
    column_count (int32_t): Sets the "ColumnCount" filter property
    column_montage_limits (IntVec2Type): Sets the "ColumnMontageLimits" filter property
    row_montage_limits (IntVec2Type): Sets the "RowMontageLimits" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ImportZenInfoMontage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if montage_name is not None:
    filter.MontageName = montage_name
  if length_unit is not None:
    filter.LengthUnit = length_unit
  if input_file is not None:
    filter.InputFile = input_file
  if data_container_path is not None:
    filter.DataContainerPath = data_container_path
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if image_data_array_name is not None:
    filter.ImageDataArrayName = image_data_array_name
  if convert_to_gray_scale is not None:
    filter.ConvertToGrayScale = convert_to_gray_scale
  if color_weights is not None:
    filter.ColorWeights = color_weights
  if change_origin is not None:
    filter.ChangeOrigin = change_origin
  if origin is not None:
    filter.Origin = origin
  if change_spacing is not None:
    filter.ChangeSpacing = change_spacing
  if spacing is not None:
    filter.Spacing = spacing
  if row_count is not None:
    filter.RowCount = row_count
  if column_count is not None:
    filter.ColumnCount = column_count
  if column_montage_limits is not None:
    filter.ColumnMontageLimits = column_montage_limits
  if row_montage_limits is not None:
    filter.RowMontageLimits = row_montage_limits
  filter.execute()
  return filter.ErrorCode

def apply_dewarp_parameters(data_container_array, montage_name = None, use_data_array = None, attribute_matrix_name = None, mask_name = None, transform_path = None, transform_prefix = None, observer = None) -> int:
  """Pythonic interface to ApplyDewarpParameters Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    montage_name (QString): Sets the "MontageName" filter property
    use_data_array (bool): Sets the "UseDataArray" filter property
    attribute_matrix_name (QString): Sets the "AttributeMatrixName" filter property
    mask_name (QString): Sets the "MaskName" filter property
    transform_path (DataArrayPath): Sets the "TransformPath" filter property
    transform_prefix (QString): Sets the "TransformPrefix" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ApplyDewarpParameters()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if montage_name is not None:
    filter.MontageName = montage_name
  if use_data_array is not None:
    filter.UseDataArray = use_data_array
  if attribute_matrix_name is not None:
    filter.AttributeMatrixName = attribute_matrix_name
  if mask_name is not None:
    filter.MaskName = mask_name
  if transform_path is not None:
    filter.TransformPath = transform_path
  if transform_prefix is not None:
    filter.TransformPrefix = transform_prefix
  filter.execute()
  return filter.ErrorCode

def calc_dewarp_parameters(data_container_array, montage_name = None, max_iterations = None, fractional_tolerance = None, delta = None, specify_initial_simplex = None, x_factors = None, y_factors = None, attribute_matrix_name = None, ipf_colors_array_name = None, transform_dc_name = None, transform_matrix_name = None, transform_array_name = None, observer = None) -> int:
  """Pythonic interface to CalcDewarpParameters Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    montage_name (QString): Sets the "MontageName" filter property
    max_iterations (uint32_t): Sets the "MaxIterations" filter property
    fractional_tolerance (double): Sets the "FractionalTolerance" filter property
    delta (int): Sets the "Delta" filter property
    specify_initial_simplex (bool): Sets the "SpecifyInitialSimplex" filter property
    x_factors (FloatVec7Type): Sets the "XFactors" filter property
    y_factors (FloatVec7Type): Sets the "YFactors" filter property
    attribute_matrix_name (QString): Sets the "AttributeMatrixName" filter property
    ipf_colors_array_name (QString): Sets the "IPFColorsArrayName" filter property
    transform_dc_name (QString): Sets the "TransformDCName" filter property
    transform_matrix_name (QString): Sets the "TransformMatrixName" filter property
    transform_array_name (QString): Sets the "TransformArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.CalcDewarpParameters()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if montage_name is not None:
    filter.MontageName = montage_name
  if max_iterations is not None:
    filter.MaxIterations = max_iterations
  if fractional_tolerance is not None:
    filter.FractionalTolerance = fractional_tolerance
  if delta is not None:
    filter.Delta = delta
  if specify_initial_simplex is not None:
    filter.SpecifyInitialSimplex = specify_initial_simplex
  if x_factors is not None:
    filter.XFactors = x_factors
  if y_factors is not None:
    filter.YFactors = y_factors
  if attribute_matrix_name is not None:
    filter.AttributeMatrixName = attribute_matrix_name
  if ipf_colors_array_name is not None:
    filter.IPFColorsArrayName = ipf_colors_array_name
  if transform_dc_name is not None:
    filter.TransformDCName = transform_dc_name
  if transform_matrix_name is not None:
    filter.TransformMatrixName = transform_matrix_name
  if transform_array_name is not None:
    filter.TransformArrayName = transform_array_name
  filter.execute()
  return filter.ErrorCode

def itk_image_reader(data_container_array, file_name = None, data_container_name = None, cell_attribute_matrix_name = None, image_data_array_name = None, observer = None) -> int:
  """Pythonic interface to ITKImageReader Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    file_name (QString): Sets the "FileName" filter property
    data_container_name (DataArrayPath): Sets the "DataContainerName" filter property
    cell_attribute_matrix_name (QString): Sets the "CellAttributeMatrixName" filter property
    image_data_array_name (QString): Sets the "ImageDataArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKImageReader()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if file_name is not None:
    filter.FileName = file_name
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if image_data_array_name is not None:
    filter.ImageDataArrayName = image_data_array_name
  filter.execute()
  return filter.ErrorCode

def itk_image_writer(data_container_array, file_name = None, image_array_path = None, plane = None, index_offset = None, observer = None) -> int:
  """Pythonic interface to ITKImageWriter Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    file_name (QString): Sets the "FileName" filter property
    image_array_path (DataArrayPath): Sets the "ImageArrayPath" filter property
    plane (int): Sets the "Plane" filter property
    index_offset (int): Sets the "IndexOffset" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKImageWriter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if file_name is not None:
    filter.FileName = file_name
  if image_array_path is not None:
    filter.ImageArrayPath = image_array_path
  if plane is not None:
    filter.Plane = plane
  if index_offset is not None:
    filter.IndexOffset = index_offset
  filter.execute()
  return filter.ErrorCode

def itk_import_image_stack(data_container_array, data_container_name = None, cell_attribute_matrix_name = None, origin = None, spacing = None, input_file_list_info = None, image_stack = None, image_data_array_name = None, observer = None) -> int:
  """Pythonic interface to ITKImportImageStack Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    data_container_name (DataArrayPath): Sets the "DataContainerName" filter property
    cell_attribute_matrix_name (QString): Sets the "CellAttributeMatrixName" filter property
    origin (FloatVec3Type): Sets the "Origin" filter property
    spacing (FloatVec3Type): Sets the "Spacing" filter property
    input_file_list_info (StackFileListInfo): Sets the "InputFileListInfo" filter property
    image_stack (int): Sets the "ImageStack" filter property
    image_data_array_name (QString): Sets the "ImageDataArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKImportImageStack()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if origin is not None:
    filter.Origin = origin
  if spacing is not None:
    filter.Spacing = spacing
  if input_file_list_info is not None:
    filter.InputFileListInfo = input_file_list_info
  if image_stack is not None:
    filter.ImageStack = image_stack
  if image_data_array_name is not None:
    filter.ImageDataArrayName = image_data_array_name
  filter.execute()
  return filter.ErrorCode

def import_vector_image_stack(data_container_array, data_container_name = None, cell_attribute_matrix_name = None, origin = None, spacing = None, input_file_list_info = None, vector_data_array_name = None, convert_to_grayscale = None, observer = None) -> int:
  """Pythonic interface to ImportVectorImageStack Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    data_container_name (DataArrayPath): Sets the "DataContainerName" filter property
    cell_attribute_matrix_name (QString): Sets the "CellAttributeMatrixName" filter property
    origin (FloatVec3Type): Sets the "Origin" filter property
    spacing (FloatVec3Type): Sets the "Spacing" filter property
    input_file_list_info (VectorFileListInfo_t): Sets the "InputFileListInfo" filter property
    vector_data_array_name (QString): Sets the "VectorDataArrayName" filter property
    convert_to_grayscale (bool): Sets the "ConvertToGrayscale" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ImportVectorImageStack()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if origin is not None:
    filter.Origin = origin
  if spacing is not None:
    filter.Spacing = spacing
  if input_file_list_info is not None:
    filter.InputFileListInfo = input_file_list_info
  if vector_data_array_name is not None:
    filter.VectorDataArrayName = vector_data_array_name
  if convert_to_grayscale is not None:
    filter.ConvertToGrayscale = convert_to_grayscale
  filter.execute()
  return filter.ErrorCode

def itk_refine_tile_coordinates(data_container_array, montage_size = None, data_containers = None, common_attribute_matrix_name = None, common_data_array_name = None, import_mode = None, tile_overlap = None, apply_refined_origin = None, observer = None) -> int:
  """Pythonic interface to ITKRefineTileCoordinates Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    montage_size (IntVec3Type): Sets the "MontageSize" filter property
    data_containers (std::vector<QString>): Sets the "DataContainers" filter property
    common_attribute_matrix_name (QString): Sets the "CommonAttributeMatrixName" filter property
    common_data_array_name (QString): Sets the "CommonDataArrayName" filter property
    import_mode (int): Sets the "ImportMode" filter property
    tile_overlap (float): Sets the "TileOverlap" filter property
    apply_refined_origin (bool): Sets the "ApplyRefinedOrigin" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKRefineTileCoordinates()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if montage_size is not None:
    filter.MontageSize = montage_size
  if data_containers is not None:
    filter.DataContainers = data_containers
  if common_attribute_matrix_name is not None:
    filter.CommonAttributeMatrixName = common_attribute_matrix_name
  if common_data_array_name is not None:
    filter.CommonDataArrayName = common_data_array_name
  if import_mode is not None:
    filter.ImportMode = import_mode
  if tile_overlap is not None:
    filter.TileOverlap = tile_overlap
  if apply_refined_origin is not None:
    filter.ApplyRefinedOrigin = apply_refined_origin
  filter.execute()
  return filter.ErrorCode

def itk_import_fiji_montage(data_container_array, montage_name = None, length_unit = None, input_file = None, data_container_path = None, cell_attribute_matrix_name = None, image_data_array_name = None, convert_to_gray_scale = None, color_weights = None, change_origin = None, origin = None, change_spacing = None, spacing = None, column_montage_limits = None, row_montage_limits = None, observer = None) -> int:
  """Pythonic interface to ITKImportFijiMontage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    montage_name (QString): Sets the "MontageName" filter property
    length_unit (int32_t): Sets the "LengthUnit" filter property
    input_file (QString): Sets the "InputFile" filter property
    data_container_path (DataArrayPath): Sets the "DataContainerPath" filter property
    cell_attribute_matrix_name (QString): Sets the "CellAttributeMatrixName" filter property
    image_data_array_name (QString): Sets the "ImageDataArrayName" filter property
    convert_to_gray_scale (bool): Sets the "ConvertToGrayScale" filter property
    color_weights (FloatVec3Type): Sets the "ColorWeights" filter property
    change_origin (bool): Sets the "ChangeOrigin" filter property
    origin (FloatVec3Type): Sets the "Origin" filter property
    change_spacing (bool): Sets the "ChangeSpacing" filter property
    spacing (FloatVec3Type): Sets the "Spacing" filter property
    column_montage_limits (IntVec2Type): Sets the "ColumnMontageLimits" filter property
    row_montage_limits (IntVec2Type): Sets the "RowMontageLimits" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKImportFijiMontage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if montage_name is not None:
    filter.MontageName = montage_name
  if length_unit is not None:
    filter.LengthUnit = length_unit
  if input_file is not None:
    filter.InputFile = input_file
  if data_container_path is not None:
    filter.DataContainerPath = data_container_path
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if image_data_array_name is not None:
    filter.ImageDataArrayName = image_data_array_name
  if convert_to_gray_scale is not None:
    filter.ConvertToGrayScale = convert_to_gray_scale
  if color_weights is not None:
    filter.ColorWeights = color_weights
  if change_origin is not None:
    filter.ChangeOrigin = change_origin
  if origin is not None:
    filter.Origin = origin
  if change_spacing is not None:
    filter.ChangeSpacing = change_spacing
  if spacing is not None:
    filter.Spacing = spacing
  if column_montage_limits is not None:
    filter.ColumnMontageLimits = column_montage_limits
  if row_montage_limits is not None:
    filter.RowMontageLimits = row_montage_limits
  filter.execute()
  return filter.ErrorCode

def itk_import_robo_met_montage(data_container_array, montage_name = None, length_unit = None, input_file = None, data_container_path = None, cell_attribute_matrix_name = None, image_data_array_name = None, convert_to_gray_scale = None, color_weights = None, change_origin = None, origin = None, change_spacing = None, spacing = None, slice_number = None, image_file_prefix = None, image_file_extension = None, column_montage_limits = None, row_montage_limits = None, observer = None) -> int:
  """Pythonic interface to ITKImportRoboMetMontage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    montage_name (QString): Sets the "MontageName" filter property
    length_unit (int32_t): Sets the "LengthUnit" filter property
    input_file (QString): Sets the "InputFile" filter property
    data_container_path (DataArrayPath): Sets the "DataContainerPath" filter property
    cell_attribute_matrix_name (QString): Sets the "CellAttributeMatrixName" filter property
    image_data_array_name (QString): Sets the "ImageDataArrayName" filter property
    convert_to_gray_scale (bool): Sets the "ConvertToGrayScale" filter property
    color_weights (FloatVec3Type): Sets the "ColorWeights" filter property
    change_origin (bool): Sets the "ChangeOrigin" filter property
    origin (FloatVec3Type): Sets the "Origin" filter property
    change_spacing (bool): Sets the "ChangeSpacing" filter property
    spacing (FloatVec3Type): Sets the "Spacing" filter property
    slice_number (int): Sets the "SliceNumber" filter property
    image_file_prefix (QString): Sets the "ImageFilePrefix" filter property
    image_file_extension (QString): Sets the "ImageFileExtension" filter property
    column_montage_limits (IntVec2Type): Sets the "ColumnMontageLimits" filter property
    row_montage_limits (IntVec2Type): Sets the "RowMontageLimits" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKImportRoboMetMontage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if montage_name is not None:
    filter.MontageName = montage_name
  if length_unit is not None:
    filter.LengthUnit = length_unit
  if input_file is not None:
    filter.InputFile = input_file
  if data_container_path is not None:
    filter.DataContainerPath = data_container_path
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if image_data_array_name is not None:
    filter.ImageDataArrayName = image_data_array_name
  if convert_to_gray_scale is not None:
    filter.ConvertToGrayScale = convert_to_gray_scale
  if color_weights is not None:
    filter.ColorWeights = color_weights
  if change_origin is not None:
    filter.ChangeOrigin = change_origin
  if origin is not None:
    filter.Origin = origin
  if change_spacing is not None:
    filter.ChangeSpacing = change_spacing
  if spacing is not None:
    filter.Spacing = spacing
  if slice_number is not None:
    filter.SliceNumber = slice_number
  if image_file_prefix is not None:
    filter.ImageFilePrefix = image_file_prefix
  if image_file_extension is not None:
    filter.ImageFileExtension = image_file_extension
  if column_montage_limits is not None:
    filter.ColumnMontageLimits = column_montage_limits
  if row_montage_limits is not None:
    filter.RowMontageLimits = row_montage_limits
  filter.execute()
  return filter.ErrorCode

def itkh_convex_image(data_container_array, height = None, fully_connected = None, observer = None) -> int:
  """Pythonic interface to ITKHConvexImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    height (double): Sets the "Height" filter property
    fully_connected (bool): Sets the "FullyConnected" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKHConvexImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if height is not None:
    filter.Height = height
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  filter.execute()
  return filter.ErrorCode

def itk_discrete_gaussian_image(data_container_array, variance = None, maximum_kernel_width = None, maximum_error = None, use_image_spacing = None, observer = None) -> int:
  """Pythonic interface to ITKDiscreteGaussianImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    variance (FloatVec3Type): Sets the "Variance" filter property
    maximum_kernel_width (int32_t): Sets the "MaximumKernelWidth" filter property
    maximum_error (FloatVec3Type): Sets the "MaximumError" filter property
    use_image_spacing (bool): Sets the "UseImageSpacing" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKDiscreteGaussianImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if variance is not None:
    filter.Variance = variance
  if maximum_kernel_width is not None:
    filter.MaximumKernelWidth = maximum_kernel_width
  if maximum_error is not None:
    filter.MaximumError = maximum_error
  if use_image_spacing is not None:
    filter.UseImageSpacing = use_image_spacing
  filter.execute()
  return filter.ErrorCode

def itk_median_image(data_container_array, radius = None, observer = None) -> int:
  """Pythonic interface to ITKMedianImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    radius (FloatVec3Type): Sets the "Radius" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKMedianImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if radius is not None:
    filter.Radius = radius
  filter.execute()
  return filter.ErrorCode

def itk_abs_image(data_container_array, observer = None) -> int:
  """Pythonic interface to ITKAbsImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKAbsImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  filter.execute()
  return filter.ErrorCode

def itk_box_mean_image(data_container_array, radius = None, observer = None) -> int:
  """Pythonic interface to ITKBoxMeanImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    radius (FloatVec3Type): Sets the "Radius" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKBoxMeanImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if radius is not None:
    filter.Radius = radius
  filter.execute()
  return filter.ErrorCode

def itk_acos_image(data_container_array, observer = None) -> int:
  """Pythonic interface to ITKAcosImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKAcosImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  filter.execute()
  return filter.ErrorCode

def itk_atan_image(data_container_array, observer = None) -> int:
  """Pythonic interface to ITKAtanImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKAtanImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  filter.execute()
  return filter.ErrorCode

def itk_min_max_curvature_flow_image(data_container_array, time_step = None, number_of_iterations = None, stencil_radius = None, observer = None) -> int:
  """Pythonic interface to ITKMinMaxCurvatureFlowImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    time_step (double): Sets the "TimeStep" filter property
    number_of_iterations (double): Sets the "NumberOfIterations" filter property
    stencil_radius (int): Sets the "StencilRadius" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKMinMaxCurvatureFlowImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if time_step is not None:
    filter.TimeStep = time_step
  if number_of_iterations is not None:
    filter.NumberOfIterations = number_of_iterations
  if stencil_radius is not None:
    filter.StencilRadius = stencil_radius
  filter.execute()
  return filter.ErrorCode

def itk_sigmoid_image(data_container_array, alpha = None, beta = None, output_maximum = None, output_minimum = None, observer = None) -> int:
  """Pythonic interface to ITKSigmoidImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    alpha (double): Sets the "Alpha" filter property
    beta (double): Sets the "Beta" filter property
    output_maximum (double): Sets the "OutputMaximum" filter property
    output_minimum (double): Sets the "OutputMinimum" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKSigmoidImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if alpha is not None:
    filter.Alpha = alpha
  if beta is not None:
    filter.Beta = beta
  if output_maximum is not None:
    filter.OutputMaximum = output_maximum
  if output_minimum is not None:
    filter.OutputMinimum = output_minimum
  filter.execute()
  return filter.ErrorCode

def itkh_maxima_image(data_container_array, height = None, observer = None) -> int:
  """Pythonic interface to ITKHMaximaImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    height (double): Sets the "Height" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKHMaximaImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if height is not None:
    filter.Height = height
  filter.execute()
  return filter.ErrorCode

def itk_curvature_anisotropic_diffusion_image(data_container_array, time_step = None, conductance_parameter = None, conductance_scaling_update_interval = None, number_of_iterations = None, observer = None) -> int:
  """Pythonic interface to ITKCurvatureAnisotropicDiffusionImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    time_step (double): Sets the "TimeStep" filter property
    conductance_parameter (double): Sets the "ConductanceParameter" filter property
    conductance_scaling_update_interval (double): Sets the "ConductanceScalingUpdateInterval" filter property
    number_of_iterations (double): Sets the "NumberOfIterations" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKCurvatureAnisotropicDiffusionImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if time_step is not None:
    filter.TimeStep = time_step
  if conductance_parameter is not None:
    filter.ConductanceParameter = conductance_parameter
  if conductance_scaling_update_interval is not None:
    filter.ConductanceScalingUpdateInterval = conductance_scaling_update_interval
  if number_of_iterations is not None:
    filter.NumberOfIterations = number_of_iterations
  filter.execute()
  return filter.ErrorCode

def itkh_minima_image(data_container_array, height = None, fully_connected = None, observer = None) -> int:
  """Pythonic interface to ITKHMinimaImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    height (double): Sets the "Height" filter property
    fully_connected (bool): Sets the "FullyConnected" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKHMinimaImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if height is not None:
    filter.Height = height
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  filter.execute()
  return filter.ErrorCode

def itk_binomial_blur_image(data_container_array, repetitions = None, observer = None) -> int:
  """Pythonic interface to ITKBinomialBlurImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    repetitions (double): Sets the "Repetitions" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKBinomialBlurImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if repetitions is not None:
    filter.Repetitions = repetitions
  filter.execute()
  return filter.ErrorCode

def itk_rescale_intensity_image(data_container_array, output_minimum = None, output_maximum = None, output_type = None, observer = None) -> int:
  """Pythonic interface to ITKRescaleIntensityImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    output_minimum (double): Sets the "OutputMinimum" filter property
    output_maximum (double): Sets the "OutputMaximum" filter property
    output_type (int): Sets the "OutputType" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKRescaleIntensityImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_minimum is not None:
    filter.OutputMinimum = output_minimum
  if output_maximum is not None:
    filter.OutputMaximum = output_maximum
  if output_type is not None:
    filter.OutputType = output_type
  filter.execute()
  return filter.ErrorCode

def itk_label_contour_image(data_container_array, fully_connected = None, background_value = None, observer = None) -> int:
  """Pythonic interface to ITKLabelContourImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    fully_connected (bool): Sets the "FullyConnected" filter property
    background_value (double): Sets the "BackgroundValue" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKLabelContourImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  if background_value is not None:
    filter.BackgroundValue = background_value
  filter.execute()
  return filter.ErrorCode

def itk_salt_and_pepper_noise_image(data_container_array, probability = None, seed = None, observer = None) -> int:
  """Pythonic interface to ITKSaltAndPepperNoiseImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    probability (double): Sets the "Probability" filter property
    seed (double): Sets the "Seed" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKSaltAndPepperNoiseImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if probability is not None:
    filter.Probability = probability
  if seed is not None:
    filter.Seed = seed
  filter.execute()
  return filter.ErrorCode

def itk_minimum_projection_image(data_container_array, projection_dimension = None, observer = None) -> int:
  """Pythonic interface to ITKMinimumProjectionImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    projection_dimension (double): Sets the "ProjectionDimension" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKMinimumProjectionImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if projection_dimension is not None:
    filter.ProjectionDimension = projection_dimension
  filter.execute()
  return filter.ErrorCode

def itk_binary_contour_image(data_container_array, fully_connected = None, background_value = None, foreground_value = None, observer = None) -> int:
  """Pythonic interface to ITKBinaryContourImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    fully_connected (bool): Sets the "FullyConnected" filter property
    background_value (double): Sets the "BackgroundValue" filter property
    foreground_value (double): Sets the "ForegroundValue" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKBinaryContourImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  if background_value is not None:
    filter.BackgroundValue = background_value
  if foreground_value is not None:
    filter.ForegroundValue = foreground_value
  filter.execute()
  return filter.ErrorCode

def itk_median_projection_image(data_container_array, projection_dimension = None, observer = None) -> int:
  """Pythonic interface to ITKMedianProjectionImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    projection_dimension (double): Sets the "ProjectionDimension" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKMedianProjectionImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if projection_dimension is not None:
    filter.ProjectionDimension = projection_dimension
  filter.execute()
  return filter.ErrorCode

def itk_shot_noise_image(data_container_array, scale = None, seed = None, observer = None) -> int:
  """Pythonic interface to ITKShotNoiseImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    scale (double): Sets the "Scale" filter property
    seed (double): Sets the "Seed" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKShotNoiseImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if scale is not None:
    filter.Scale = scale
  if seed is not None:
    filter.Seed = seed
  filter.execute()
  return filter.ErrorCode

def itk_maximum_projection_image(data_container_array, projection_dimension = None, observer = None) -> int:
  """Pythonic interface to ITKMaximumProjectionImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    projection_dimension (double): Sets the "ProjectionDimension" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKMaximumProjectionImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if projection_dimension is not None:
    filter.ProjectionDimension = projection_dimension
  filter.execute()
  return filter.ErrorCode

def itk_speckle_noise_image(data_container_array, standard_deviation = None, seed = None, observer = None) -> int:
  """Pythonic interface to ITKSpeckleNoiseImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    standard_deviation (double): Sets the "StandardDeviation" filter property
    seed (double): Sets the "Seed" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKSpeckleNoiseImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if standard_deviation is not None:
    filter.StandardDeviation = standard_deviation
  if seed is not None:
    filter.Seed = seed
  filter.execute()
  return filter.ErrorCode

def itk_shift_scale_image(data_container_array, shift = None, scale = None, observer = None) -> int:
  """Pythonic interface to ITKShiftScaleImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    shift (double): Sets the "Shift" filter property
    scale (double): Sets the "Scale" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKShiftScaleImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if shift is not None:
    filter.Shift = shift
  if scale is not None:
    filter.Scale = scale
  filter.execute()
  return filter.ErrorCode

def itk_binary_projection_image(data_container_array, projection_dimension = None, foreground_value = None, background_value = None, observer = None) -> int:
  """Pythonic interface to ITKBinaryProjectionImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    projection_dimension (double): Sets the "ProjectionDimension" filter property
    foreground_value (double): Sets the "ForegroundValue" filter property
    background_value (double): Sets the "BackgroundValue" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKBinaryProjectionImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if projection_dimension is not None:
    filter.ProjectionDimension = projection_dimension
  if foreground_value is not None:
    filter.ForegroundValue = foreground_value
  if background_value is not None:
    filter.BackgroundValue = background_value
  filter.execute()
  return filter.ErrorCode

def itk_invert_intensity_image(data_container_array, maximum = None, observer = None) -> int:
  """Pythonic interface to ITKInvertIntensityImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    maximum (double): Sets the "Maximum" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKInvertIntensityImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if maximum is not None:
    filter.Maximum = maximum
  filter.execute()
  return filter.ErrorCode

def itk_grayscale_fillhole_image(data_container_array, fully_connected = None, observer = None) -> int:
  """Pythonic interface to ITKGrayscaleFillholeImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    fully_connected (bool): Sets the "FullyConnected" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKGrayscaleFillholeImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  filter.execute()
  return filter.ErrorCode

def itk_asin_image(data_container_array, observer = None) -> int:
  """Pythonic interface to ITKAsinImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKAsinImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  filter.execute()
  return filter.ErrorCode

def itk_intensity_windowing_image(data_container_array, window_minimum = None, window_maximum = None, output_minimum = None, output_maximum = None, observer = None) -> int:
  """Pythonic interface to ITKIntensityWindowingImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    window_minimum (double): Sets the "WindowMinimum" filter property
    window_maximum (double): Sets the "WindowMaximum" filter property
    output_minimum (double): Sets the "OutputMinimum" filter property
    output_maximum (double): Sets the "OutputMaximum" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKIntensityWindowingImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if window_minimum is not None:
    filter.WindowMinimum = window_minimum
  if window_maximum is not None:
    filter.WindowMaximum = window_maximum
  if output_minimum is not None:
    filter.OutputMinimum = output_minimum
  if output_maximum is not None:
    filter.OutputMaximum = output_maximum
  filter.execute()
  return filter.ErrorCode

def itk_gradient_anisotropic_diffusion_image(data_container_array, time_step = None, conductance_parameter = None, conductance_scaling_update_interval = None, number_of_iterations = None, observer = None) -> int:
  """Pythonic interface to ITKGradientAnisotropicDiffusionImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    time_step (double): Sets the "TimeStep" filter property
    conductance_parameter (double): Sets the "ConductanceParameter" filter property
    conductance_scaling_update_interval (double): Sets the "ConductanceScalingUpdateInterval" filter property
    number_of_iterations (double): Sets the "NumberOfIterations" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKGradientAnisotropicDiffusionImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if time_step is not None:
    filter.TimeStep = time_step
  if conductance_parameter is not None:
    filter.ConductanceParameter = conductance_parameter
  if conductance_scaling_update_interval is not None:
    filter.ConductanceScalingUpdateInterval = conductance_scaling_update_interval
  if number_of_iterations is not None:
    filter.NumberOfIterations = number_of_iterations
  filter.execute()
  return filter.ErrorCode

def itk_valued_regional_minima_image(data_container_array, fully_connected = None, flat = None, observer = None) -> int:
  """Pythonic interface to ITKValuedRegionalMinimaImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    fully_connected (bool): Sets the "FullyConnected" filter property
    flat (bool): Sets the "Flat" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKValuedRegionalMinimaImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  if flat is not None:
    filter.Flat = flat
  filter.execute()
  return filter.ErrorCode

def itk_bilateral_image(data_container_array, domain_sigma = None, range_sigma = None, number_of_range_gaussian_samples = None, observer = None) -> int:
  """Pythonic interface to ITKBilateralImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    domain_sigma (double): Sets the "DomainSigma" filter property
    range_sigma (double): Sets the "RangeSigma" filter property
    number_of_range_gaussian_samples (double): Sets the "NumberOfRangeGaussianSamples" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKBilateralImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if domain_sigma is not None:
    filter.DomainSigma = domain_sigma
  if range_sigma is not None:
    filter.RangeSigma = range_sigma
  if number_of_range_gaussian_samples is not None:
    filter.NumberOfRangeGaussianSamples = number_of_range_gaussian_samples
  filter.execute()
  return filter.ErrorCode

def itk_valued_regional_maxima_image(data_container_array, fully_connected = None, flat = None, observer = None) -> int:
  """Pythonic interface to ITKValuedRegionalMaximaImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    fully_connected (bool): Sets the "FullyConnected" filter property
    flat (bool): Sets the "Flat" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKValuedRegionalMaximaImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  if flat is not None:
    filter.Flat = flat
  filter.execute()
  return filter.ErrorCode

def itk_relabel_component_image(data_container_array, minimum_object_size = None, sort_by_object_size = None, number_of_objects = None, original_number_of_objects = None, size_of_objects_in_physical_units = None, size_of_objects_in_pixels = None, observer = None) -> int:
  """Pythonic interface to ITKRelabelComponentImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    minimum_object_size (double): Sets the "MinimumObjectSize" filter property
    sort_by_object_size (bool): Sets the "SortByObjectSize" filter property
    number_of_objects (double): Sets the "NumberOfObjects" filter property
    original_number_of_objects (double): Sets the "OriginalNumberOfObjects" filter property
    size_of_objects_in_physical_units (FloatVec3Type): Sets the "SizeOfObjectsInPhysicalUnits" filter property
    size_of_objects_in_pixels (FloatVec3Type): Sets the "SizeOfObjectsInPixels" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKRelabelComponentImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if minimum_object_size is not None:
    filter.MinimumObjectSize = minimum_object_size
  if sort_by_object_size is not None:
    filter.SortByObjectSize = sort_by_object_size
  if number_of_objects is not None:
    filter.NumberOfObjects = number_of_objects
  if original_number_of_objects is not None:
    filter.OriginalNumberOfObjects = original_number_of_objects
  if size_of_objects_in_physical_units is not None:
    filter.SizeOfObjectsInPhysicalUnits = size_of_objects_in_physical_units
  if size_of_objects_in_pixels is not None:
    filter.SizeOfObjectsInPixels = size_of_objects_in_pixels
  filter.execute()
  return filter.ErrorCode

def itk_grayscale_grind_peak_image(data_container_array, fully_connected = None, observer = None) -> int:
  """Pythonic interface to ITKGrayscaleGrindPeakImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    fully_connected (bool): Sets the "FullyConnected" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKGrayscaleGrindPeakImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  filter.execute()
  return filter.ErrorCode

def itk_laplacian_sharpening_image(data_container_array, use_image_spacing = None, observer = None) -> int:
  """Pythonic interface to ITKLaplacianSharpeningImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    use_image_spacing (bool): Sets the "UseImageSpacing" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKLaplacianSharpeningImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if use_image_spacing is not None:
    filter.UseImageSpacing = use_image_spacing
  filter.execute()
  return filter.ErrorCode

def itk_binary_threshold_image(data_container_array, lower_threshold = None, upper_threshold = None, inside_value = None, outside_value = None, observer = None) -> int:
  """Pythonic interface to ITKBinaryThresholdImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    lower_threshold (double): Sets the "LowerThreshold" filter property
    upper_threshold (double): Sets the "UpperThreshold" filter property
    inside_value (int): Sets the "InsideValue" filter property
    outside_value (int): Sets the "OutsideValue" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKBinaryThresholdImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if lower_threshold is not None:
    filter.LowerThreshold = lower_threshold
  if upper_threshold is not None:
    filter.UpperThreshold = upper_threshold
  if inside_value is not None:
    filter.InsideValue = inside_value
  if outside_value is not None:
    filter.OutsideValue = outside_value
  filter.execute()
  return filter.ErrorCode

def itk_gradient_magnitude_image(data_container_array, use_image_spacing = None, observer = None) -> int:
  """Pythonic interface to ITKGradientMagnitudeImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    use_image_spacing (bool): Sets the "UseImageSpacing" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKGradientMagnitudeImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if use_image_spacing is not None:
    filter.UseImageSpacing = use_image_spacing
  filter.execute()
  return filter.ErrorCode

def itk_signed_maurer_distance_map_image(data_container_array, inside_is_positive = None, squared_distance = None, use_image_spacing = None, background_value = None, observer = None) -> int:
  """Pythonic interface to ITKSignedMaurerDistanceMapImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    inside_is_positive (bool): Sets the "InsideIsPositive" filter property
    squared_distance (bool): Sets the "SquaredDistance" filter property
    use_image_spacing (bool): Sets the "UseImageSpacing" filter property
    background_value (double): Sets the "BackgroundValue" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKSignedMaurerDistanceMapImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if inside_is_positive is not None:
    filter.InsideIsPositive = inside_is_positive
  if squared_distance is not None:
    filter.SquaredDistance = squared_distance
  if use_image_spacing is not None:
    filter.UseImageSpacing = use_image_spacing
  if background_value is not None:
    filter.BackgroundValue = background_value
  filter.execute()
  return filter.ErrorCode

def itk_laplacian_recursive_gaussian_image(data_container_array, sigma = None, normalize_across_scale = None, observer = None) -> int:
  """Pythonic interface to ITKLaplacianRecursiveGaussianImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    sigma (double): Sets the "Sigma" filter property
    normalize_across_scale (bool): Sets the "NormalizeAcrossScale" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKLaplacianRecursiveGaussianImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if sigma is not None:
    filter.Sigma = sigma
  if normalize_across_scale is not None:
    filter.NormalizeAcrossScale = normalize_across_scale
  filter.execute()
  return filter.ErrorCode

def itk_gradient_magnitude_recursive_gaussian_image(data_container_array, sigma = None, normalize_across_scale = None, observer = None) -> int:
  """Pythonic interface to ITKGradientMagnitudeRecursiveGaussianImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    sigma (double): Sets the "Sigma" filter property
    normalize_across_scale (bool): Sets the "NormalizeAcrossScale" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKGradientMagnitudeRecursiveGaussianImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if sigma is not None:
    filter.Sigma = sigma
  if normalize_across_scale is not None:
    filter.NormalizeAcrossScale = normalize_across_scale
  filter.execute()
  return filter.ErrorCode

def itk_otsu_multiple_thresholds_image(data_container_array, number_of_thresholds = None, label_offset = None, number_of_histogram_bins = None, valley_emphasis = None, thresholds = None, observer = None) -> int:
  """Pythonic interface to ITKOtsuMultipleThresholdsImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    number_of_thresholds (int): Sets the "NumberOfThresholds" filter property
    label_offset (int): Sets the "LabelOffset" filter property
    number_of_histogram_bins (double): Sets the "NumberOfHistogramBins" filter property
    valley_emphasis (bool): Sets the "ValleyEmphasis" filter property
    thresholds (FloatVec3Type): Sets the "Thresholds" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKOtsuMultipleThresholdsImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if number_of_thresholds is not None:
    filter.NumberOfThresholds = number_of_thresholds
  if label_offset is not None:
    filter.LabelOffset = label_offset
  if number_of_histogram_bins is not None:
    filter.NumberOfHistogramBins = number_of_histogram_bins
  if valley_emphasis is not None:
    filter.ValleyEmphasis = valley_emphasis
  if thresholds is not None:
    filter.Thresholds = thresholds
  filter.execute()
  return filter.ErrorCode

def itk_double_threshold_image(data_container_array, threshold1 = None, threshold2 = None, threshold3 = None, threshold4 = None, inside_value = None, outside_value = None, fully_connected = None, observer = None) -> int:
  """Pythonic interface to ITKDoubleThresholdImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    threshold1 (double): Sets the "Threshold1" filter property
    threshold2 (double): Sets the "Threshold2" filter property
    threshold3 (double): Sets the "Threshold3" filter property
    threshold4 (double): Sets the "Threshold4" filter property
    inside_value (int): Sets the "InsideValue" filter property
    outside_value (int): Sets the "OutsideValue" filter property
    fully_connected (bool): Sets the "FullyConnected" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKDoubleThresholdImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if threshold1 is not None:
    filter.Threshold1 = threshold1
  if threshold2 is not None:
    filter.Threshold2 = threshold2
  if threshold3 is not None:
    filter.Threshold3 = threshold3
  if threshold4 is not None:
    filter.Threshold4 = threshold4
  if inside_value is not None:
    filter.InsideValue = inside_value
  if outside_value is not None:
    filter.OutsideValue = outside_value
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  filter.execute()
  return filter.ErrorCode

def itk_sum_projection_image(data_container_array, projection_dimension = None, observer = None) -> int:
  """Pythonic interface to ITKSumProjectionImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    projection_dimension (double): Sets the "ProjectionDimension" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKSumProjectionImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if projection_dimension is not None:
    filter.ProjectionDimension = projection_dimension
  filter.execute()
  return filter.ErrorCode

def itk_approximate_signed_distance_map_image(data_container_array, inside_value = None, outside_value = None, observer = None) -> int:
  """Pythonic interface to ITKApproximateSignedDistanceMapImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    inside_value (double): Sets the "InsideValue" filter property
    outside_value (double): Sets the "OutsideValue" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKApproximateSignedDistanceMapImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if inside_value is not None:
    filter.InsideValue = inside_value
  if outside_value is not None:
    filter.OutsideValue = outside_value
  filter.execute()
  return filter.ErrorCode

def itk_curvature_flow_image(data_container_array, time_step = None, number_of_iterations = None, observer = None) -> int:
  """Pythonic interface to ITKCurvatureFlowImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    time_step (double): Sets the "TimeStep" filter property
    number_of_iterations (double): Sets the "NumberOfIterations" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKCurvatureFlowImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if time_step is not None:
    filter.TimeStep = time_step
  if number_of_iterations is not None:
    filter.NumberOfIterations = number_of_iterations
  filter.execute()
  return filter.ErrorCode

def itk_iso_contour_distance_image(data_container_array, level_set_value = None, far_value = None, observer = None) -> int:
  """Pythonic interface to ITKIsoContourDistanceImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    level_set_value (double): Sets the "LevelSetValue" filter property
    far_value (double): Sets the "FarValue" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKIsoContourDistanceImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if level_set_value is not None:
    filter.LevelSetValue = level_set_value
  if far_value is not None:
    filter.FarValue = far_value
  filter.execute()
  return filter.ErrorCode

def itk_regional_minima_image(data_container_array, background_value = None, foreground_value = None, fully_connected = None, flat_is_minima = None, observer = None) -> int:
  """Pythonic interface to ITKRegionalMinimaImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    background_value (double): Sets the "BackgroundValue" filter property
    foreground_value (double): Sets the "ForegroundValue" filter property
    fully_connected (bool): Sets the "FullyConnected" filter property
    flat_is_minima (bool): Sets the "FlatIsMinima" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKRegionalMinimaImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if background_value is not None:
    filter.BackgroundValue = background_value
  if foreground_value is not None:
    filter.ForegroundValue = foreground_value
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  if flat_is_minima is not None:
    filter.FlatIsMinima = flat_is_minima
  filter.execute()
  return filter.ErrorCode

def itk_regional_maxima_image(data_container_array, background_value = None, foreground_value = None, fully_connected = None, flat_is_maxima = None, observer = None) -> int:
  """Pythonic interface to ITKRegionalMaximaImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    background_value (double): Sets the "BackgroundValue" filter property
    foreground_value (double): Sets the "ForegroundValue" filter property
    fully_connected (bool): Sets the "FullyConnected" filter property
    flat_is_maxima (bool): Sets the "FlatIsMaxima" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKRegionalMaximaImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if background_value is not None:
    filter.BackgroundValue = background_value
  if foreground_value is not None:
    filter.ForegroundValue = foreground_value
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  if flat_is_maxima is not None:
    filter.FlatIsMaxima = flat_is_maxima
  filter.execute()
  return filter.ErrorCode

def itk_signed_danielsson_distance_map_image(data_container_array, inside_is_positive = None, squared_distance = None, use_image_spacing = None, observer = None) -> int:
  """Pythonic interface to ITKSignedDanielssonDistanceMapImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    inside_is_positive (bool): Sets the "InsideIsPositive" filter property
    squared_distance (bool): Sets the "SquaredDistance" filter property
    use_image_spacing (bool): Sets the "UseImageSpacing" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKSignedDanielssonDistanceMapImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if inside_is_positive is not None:
    filter.InsideIsPositive = inside_is_positive
  if squared_distance is not None:
    filter.SquaredDistance = squared_distance
  if use_image_spacing is not None:
    filter.UseImageSpacing = use_image_spacing
  filter.execute()
  return filter.ErrorCode

def itk_normalize_to_constant_image(data_container_array, constant = None, observer = None) -> int:
  """Pythonic interface to ITKNormalizeToConstantImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    constant (double): Sets the "Constant" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKNormalizeToConstantImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if constant is not None:
    filter.Constant = constant
  filter.execute()
  return filter.ErrorCode

def itk_standard_deviation_projection_image(data_container_array, projection_dimension = None, observer = None) -> int:
  """Pythonic interface to ITKStandardDeviationProjectionImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    projection_dimension (double): Sets the "ProjectionDimension" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKStandardDeviationProjectionImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if projection_dimension is not None:
    filter.ProjectionDimension = projection_dimension
  filter.execute()
  return filter.ErrorCode

def itk_danielsson_distance_map_image(data_container_array, input_is_binary = None, squared_distance = None, use_image_spacing = None, observer = None) -> int:
  """Pythonic interface to ITKDanielssonDistanceMapImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    input_is_binary (bool): Sets the "InputIsBinary" filter property
    squared_distance (bool): Sets the "SquaredDistance" filter property
    use_image_spacing (bool): Sets the "UseImageSpacing" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKDanielssonDistanceMapImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if input_is_binary is not None:
    filter.InputIsBinary = input_is_binary
  if squared_distance is not None:
    filter.SquaredDistance = squared_distance
  if use_image_spacing is not None:
    filter.UseImageSpacing = use_image_spacing
  filter.execute()
  return filter.ErrorCode

def itk_mean_projection_image(data_container_array, projection_dimension = None, observer = None) -> int:
  """Pythonic interface to ITKMeanProjectionImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    projection_dimension (double): Sets the "ProjectionDimension" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKMeanProjectionImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if projection_dimension is not None:
    filter.ProjectionDimension = projection_dimension
  filter.execute()
  return filter.ErrorCode

def itk_zero_crossing_image(data_container_array, foreground_value = None, background_value = None, observer = None) -> int:
  """Pythonic interface to ITKZeroCrossingImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    foreground_value (int): Sets the "ForegroundValue" filter property
    background_value (int): Sets the "BackgroundValue" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKZeroCrossingImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if foreground_value is not None:
    filter.ForegroundValue = foreground_value
  if background_value is not None:
    filter.BackgroundValue = background_value
  filter.execute()
  return filter.ErrorCode

def itk_threshold_maximum_connected_components_image(data_container_array, minimum_object_size_in_pixels = None, upper_boundary = None, inside_value = None, outside_value = None, observer = None) -> int:
  """Pythonic interface to ITKThresholdMaximumConnectedComponentsImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    minimum_object_size_in_pixels (double): Sets the "MinimumObjectSizeInPixels" filter property
    upper_boundary (double): Sets the "UpperBoundary" filter property
    inside_value (int): Sets the "InsideValue" filter property
    outside_value (int): Sets the "OutsideValue" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKThresholdMaximumConnectedComponentsImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if minimum_object_size_in_pixels is not None:
    filter.MinimumObjectSizeInPixels = minimum_object_size_in_pixels
  if upper_boundary is not None:
    filter.UpperBoundary = upper_boundary
  if inside_value is not None:
    filter.InsideValue = inside_value
  if outside_value is not None:
    filter.OutsideValue = outside_value
  filter.execute()
  return filter.ErrorCode

def itk_smoothing_recursive_gaussian_image(data_container_array, sigma = None, normalize_across_scale = None, observer = None) -> int:
  """Pythonic interface to ITKSmoothingRecursiveGaussianImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    sigma (FloatVec3Type): Sets the "Sigma" filter property
    normalize_across_scale (bool): Sets the "NormalizeAcrossScale" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKSmoothingRecursiveGaussianImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if sigma is not None:
    filter.Sigma = sigma
  if normalize_across_scale is not None:
    filter.NormalizeAcrossScale = normalize_across_scale
  filter.execute()
  return filter.ErrorCode

def itk_adaptive_histogram_equalization_image(data_container_array, radius = None, alpha = None, beta = None, observer = None) -> int:
  """Pythonic interface to ITKAdaptiveHistogramEqualizationImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    radius (FloatVec3Type): Sets the "Radius" filter property
    alpha (float): Sets the "Alpha" filter property
    beta (float): Sets the "Beta" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKAdaptiveHistogramEqualizationImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if radius is not None:
    filter.Radius = radius
  if alpha is not None:
    filter.Alpha = alpha
  if beta is not None:
    filter.Beta = beta
  filter.execute()
  return filter.ErrorCode

def itk_cast_image(data_container_array, casting_type = None, observer = None) -> int:
  """Pythonic interface to ITKCastImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    casting_type (int): Sets the "CastingType" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKCastImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if casting_type is not None:
    filter.CastingType = casting_type
  filter.execute()
  return filter.ErrorCode

def itk_histogram_matching_image(data_container_array, reference_cell_array_path = None, number_of_histogram_levels = None, number_of_match_points = None, threshold_at_mean_intensity = None, observer = None) -> int:
  """Pythonic interface to ITKHistogramMatchingImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    reference_cell_array_path (DataArrayPath): Sets the "ReferenceCellArrayPath" filter property
    number_of_histogram_levels (double): Sets the "NumberOfHistogramLevels" filter property
    number_of_match_points (double): Sets the "NumberOfMatchPoints" filter property
    threshold_at_mean_intensity (bool): Sets the "ThresholdAtMeanIntensity" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKHistogramMatchingImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if reference_cell_array_path is not None:
    filter.ReferenceCellArrayPath = reference_cell_array_path
  if number_of_histogram_levels is not None:
    filter.NumberOfHistogramLevels = number_of_histogram_levels
  if number_of_match_points is not None:
    filter.NumberOfMatchPoints = number_of_match_points
  if threshold_at_mean_intensity is not None:
    filter.ThresholdAtMeanIntensity = threshold_at_mean_intensity
  filter.execute()
  return filter.ErrorCode

def itk_morphological_watershed_image(data_container_array, level = None, mark_watershed_line = None, fully_connected = None, observer = None) -> int:
  """Pythonic interface to ITKMorphologicalWatershedImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    level (double): Sets the "Level" filter property
    mark_watershed_line (bool): Sets the "MarkWatershedLine" filter property
    fully_connected (bool): Sets the "FullyConnected" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKMorphologicalWatershedImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if level is not None:
    filter.Level = level
  if mark_watershed_line is not None:
    filter.MarkWatershedLine = mark_watershed_line
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  filter.execute()
  return filter.ErrorCode

def itk_morphological_watershed_from_markers_image(data_container_array, mark_watershed_line = None, fully_connected = None, marker_cell_array_path = None, observer = None) -> int:
  """Pythonic interface to ITKMorphologicalWatershedFromMarkersImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    mark_watershed_line (bool): Sets the "MarkWatershedLine" filter property
    fully_connected (bool): Sets the "FullyConnected" filter property
    marker_cell_array_path (DataArrayPath): Sets the "MarkerCellArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKMorphologicalWatershedFromMarkersImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if mark_watershed_line is not None:
    filter.MarkWatershedLine = mark_watershed_line
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  if marker_cell_array_path is not None:
    filter.MarkerCellArrayPath = marker_cell_array_path
  filter.execute()
  return filter.ErrorCode

def itk_threshold_image(data_container_array, lower = None, upper = None, outside_value = None, observer = None) -> int:
  """Pythonic interface to ITKThresholdImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    lower (double): Sets the "Lower" filter property
    upper (double): Sets the "Upper" filter property
    outside_value (double): Sets the "OutsideValue" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKThresholdImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if lower is not None:
    filter.Lower = lower
  if upper is not None:
    filter.Upper = upper
  if outside_value is not None:
    filter.OutsideValue = outside_value
  filter.execute()
  return filter.ErrorCode

def itk_black_top_hat_image(data_container_array, safe_border = None, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """Pythonic interface to ITKBlackTopHatImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    safe_border (bool): Sets the "SafeBorder" filter property
    kernel_radius (FloatVec3Type): Sets the "KernelRadius" filter property
    kernel_type (int): Sets the "KernelType" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKBlackTopHatImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if safe_border is not None:
    filter.SafeBorder = safe_border
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_white_top_hat_image(data_container_array, safe_border = None, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """Pythonic interface to ITKWhiteTopHatImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    safe_border (bool): Sets the "SafeBorder" filter property
    kernel_radius (FloatVec3Type): Sets the "KernelRadius" filter property
    kernel_type (int): Sets the "KernelType" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKWhiteTopHatImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if safe_border is not None:
    filter.SafeBorder = safe_border
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_grayscale_erode_image(data_container_array, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """Pythonic interface to ITKGrayscaleErodeImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    kernel_radius (FloatVec3Type): Sets the "KernelRadius" filter property
    kernel_type (int): Sets the "KernelType" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKGrayscaleErodeImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_binary_dilate_image(data_container_array, background_value = None, foreground_value = None, boundary_to_foreground = None, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """Pythonic interface to ITKBinaryDilateImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    background_value (double): Sets the "BackgroundValue" filter property
    foreground_value (double): Sets the "ForegroundValue" filter property
    boundary_to_foreground (bool): Sets the "BoundaryToForeground" filter property
    kernel_radius (FloatVec3Type): Sets the "KernelRadius" filter property
    kernel_type (int): Sets the "KernelType" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKBinaryDilateImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if background_value is not None:
    filter.BackgroundValue = background_value
  if foreground_value is not None:
    filter.ForegroundValue = foreground_value
  if boundary_to_foreground is not None:
    filter.BoundaryToForeground = boundary_to_foreground
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_grayscale_morphological_opening_image(data_container_array, safe_border = None, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """Pythonic interface to ITKGrayscaleMorphologicalOpeningImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    safe_border (bool): Sets the "SafeBorder" filter property
    kernel_radius (FloatVec3Type): Sets the "KernelRadius" filter property
    kernel_type (int): Sets the "KernelType" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKGrayscaleMorphologicalOpeningImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if safe_border is not None:
    filter.SafeBorder = safe_border
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_grayscale_morphological_closing_image(data_container_array, safe_border = None, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """Pythonic interface to ITKGrayscaleMorphologicalClosingImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    safe_border (bool): Sets the "SafeBorder" filter property
    kernel_radius (FloatVec3Type): Sets the "KernelRadius" filter property
    kernel_type (int): Sets the "KernelType" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKGrayscaleMorphologicalClosingImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if safe_border is not None:
    filter.SafeBorder = safe_border
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_erode_object_morphology_image(data_container_array, object_value = None, background_value = None, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """Pythonic interface to ITKErodeObjectMorphologyImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    object_value (double): Sets the "ObjectValue" filter property
    background_value (double): Sets the "BackgroundValue" filter property
    kernel_radius (FloatVec3Type): Sets the "KernelRadius" filter property
    kernel_type (int): Sets the "KernelType" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKErodeObjectMorphologyImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if object_value is not None:
    filter.ObjectValue = object_value
  if background_value is not None:
    filter.BackgroundValue = background_value
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_closing_by_reconstruction_image(data_container_array, fully_connected = None, preserve_intensities = None, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """Pythonic interface to ITKClosingByReconstructionImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    fully_connected (bool): Sets the "FullyConnected" filter property
    preserve_intensities (bool): Sets the "PreserveIntensities" filter property
    kernel_radius (FloatVec3Type): Sets the "KernelRadius" filter property
    kernel_type (int): Sets the "KernelType" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKClosingByReconstructionImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  if preserve_intensities is not None:
    filter.PreserveIntensities = preserve_intensities
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_dilate_object_morphology_image(data_container_array, object_value = None, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """Pythonic interface to ITKDilateObjectMorphologyImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    object_value (double): Sets the "ObjectValue" filter property
    kernel_radius (FloatVec3Type): Sets the "KernelRadius" filter property
    kernel_type (int): Sets the "KernelType" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKDilateObjectMorphologyImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if object_value is not None:
    filter.ObjectValue = object_value
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_binary_erode_image(data_container_array, background_value = None, foreground_value = None, boundary_to_foreground = None, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """Pythonic interface to ITKBinaryErodeImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    background_value (double): Sets the "BackgroundValue" filter property
    foreground_value (double): Sets the "ForegroundValue" filter property
    boundary_to_foreground (bool): Sets the "BoundaryToForeground" filter property
    kernel_radius (FloatVec3Type): Sets the "KernelRadius" filter property
    kernel_type (int): Sets the "KernelType" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKBinaryErodeImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if background_value is not None:
    filter.BackgroundValue = background_value
  if foreground_value is not None:
    filter.ForegroundValue = foreground_value
  if boundary_to_foreground is not None:
    filter.BoundaryToForeground = boundary_to_foreground
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_morphological_gradient_image(data_container_array, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """Pythonic interface to ITKMorphologicalGradientImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    kernel_radius (FloatVec3Type): Sets the "KernelRadius" filter property
    kernel_type (int): Sets the "KernelType" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKMorphologicalGradientImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_opening_by_reconstruction_image(data_container_array, fully_connected = None, preserve_intensities = None, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """Pythonic interface to ITKOpeningByReconstructionImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    fully_connected (bool): Sets the "FullyConnected" filter property
    preserve_intensities (bool): Sets the "PreserveIntensities" filter property
    kernel_radius (FloatVec3Type): Sets the "KernelRadius" filter property
    kernel_type (int): Sets the "KernelType" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKOpeningByReconstructionImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  if preserve_intensities is not None:
    filter.PreserveIntensities = preserve_intensities
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_binary_morphological_opening_image(data_container_array, background_value = None, foreground_value = None, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """Pythonic interface to ITKBinaryMorphologicalOpeningImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    background_value (double): Sets the "BackgroundValue" filter property
    foreground_value (double): Sets the "ForegroundValue" filter property
    kernel_radius (FloatVec3Type): Sets the "KernelRadius" filter property
    kernel_type (int): Sets the "KernelType" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKBinaryMorphologicalOpeningImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if background_value is not None:
    filter.BackgroundValue = background_value
  if foreground_value is not None:
    filter.ForegroundValue = foreground_value
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_binary_opening_by_reconstruction_image(data_container_array, foreground_value = None, background_value = None, fully_connected = None, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """Pythonic interface to ITKBinaryOpeningByReconstructionImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    foreground_value (double): Sets the "ForegroundValue" filter property
    background_value (double): Sets the "BackgroundValue" filter property
    fully_connected (bool): Sets the "FullyConnected" filter property
    kernel_radius (FloatVec3Type): Sets the "KernelRadius" filter property
    kernel_type (int): Sets the "KernelType" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKBinaryOpeningByReconstructionImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if foreground_value is not None:
    filter.ForegroundValue = foreground_value
  if background_value is not None:
    filter.BackgroundValue = background_value
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_binary_morphological_closing_image(data_container_array, foreground_value = None, safe_border = None, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """Pythonic interface to ITKBinaryMorphologicalClosingImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    foreground_value (double): Sets the "ForegroundValue" filter property
    safe_border (bool): Sets the "SafeBorder" filter property
    kernel_radius (FloatVec3Type): Sets the "KernelRadius" filter property
    kernel_type (int): Sets the "KernelType" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKBinaryMorphologicalClosingImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if foreground_value is not None:
    filter.ForegroundValue = foreground_value
  if safe_border is not None:
    filter.SafeBorder = safe_border
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_binary_closing_by_reconstruction_image(data_container_array, foreground_value = None, fully_connected = None, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """Pythonic interface to ITKBinaryClosingByReconstructionImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    foreground_value (double): Sets the "ForegroundValue" filter property
    fully_connected (bool): Sets the "FullyConnected" filter property
    kernel_radius (FloatVec3Type): Sets the "KernelRadius" filter property
    kernel_type (int): Sets the "KernelType" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKBinaryClosingByReconstructionImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if foreground_value is not None:
    filter.ForegroundValue = foreground_value
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_grayscale_dilate_image(data_container_array, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """Pythonic interface to ITKGrayscaleDilateImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    kernel_radius (FloatVec3Type): Sets the "KernelRadius" filter property
    kernel_type (int): Sets the "KernelType" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKGrayscaleDilateImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_multi_scale_hessian_based_objectness_image(data_container_array, object_dimension = None, alpha = None, beta = None, gamma = None, scale_objectness_measure = None, bright_object = None, sigma_minimum = None, sigma_maximum = None, number_of_sigma_steps = None, observer = None) -> int:
  """Pythonic interface to ITKMultiScaleHessianBasedObjectnessImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    object_dimension (int): Sets the "ObjectDimension" filter property
    alpha (double): Sets the "Alpha" filter property
    beta (double): Sets the "Beta" filter property
    gamma (double): Sets the "Gamma" filter property
    scale_objectness_measure (bool): Sets the "ScaleObjectnessMeasure" filter property
    bright_object (bool): Sets the "BrightObject" filter property
    sigma_minimum (double): Sets the "SigmaMinimum" filter property
    sigma_maximum (double): Sets the "SigmaMaximum" filter property
    number_of_sigma_steps (double): Sets the "NumberOfSigmaSteps" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKMultiScaleHessianBasedObjectnessImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if object_dimension is not None:
    filter.ObjectDimension = object_dimension
  if alpha is not None:
    filter.Alpha = alpha
  if beta is not None:
    filter.Beta = beta
  if gamma is not None:
    filter.Gamma = gamma
  if scale_objectness_measure is not None:
    filter.ScaleObjectnessMeasure = scale_objectness_measure
  if bright_object is not None:
    filter.BrightObject = bright_object
  if sigma_minimum is not None:
    filter.SigmaMinimum = sigma_minimum
  if sigma_maximum is not None:
    filter.SigmaMaximum = sigma_maximum
  if number_of_sigma_steps is not None:
    filter.NumberOfSigmaSteps = number_of_sigma_steps
  filter.execute()
  return filter.ErrorCode

def itk_vector_connected_component_image(data_container_array, distance_threshold = None, fully_connected = None, observer = None) -> int:
  """Pythonic interface to ITKVectorConnectedComponentImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    distance_threshold (double): Sets the "DistanceThreshold" filter property
    fully_connected (bool): Sets the "FullyConnected" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKVectorConnectedComponentImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if distance_threshold is not None:
    filter.DistanceThreshold = distance_threshold
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  filter.execute()
  return filter.ErrorCode

def itk_connected_component_image(data_container_array, fully_connected = None, object_count = None, observer = None) -> int:
  """Pythonic interface to ITKConnectedComponentImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    fully_connected (bool): Sets the "FullyConnected" filter property
    object_count (double): Sets the "ObjectCount" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKConnectedComponentImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  if object_count is not None:
    filter.ObjectCount = object_count
  filter.execute()
  return filter.ErrorCode

def itk_mask_image(data_container_array, outside_value = None, mask_cell_array_path = None, observer = None) -> int:
  """Pythonic interface to ITKMaskImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    outside_value (double): Sets the "OutsideValue" filter property
    mask_cell_array_path (DataArrayPath): Sets the "MaskCellArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKMaskImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if outside_value is not None:
    filter.OutsideValue = outside_value
  if mask_cell_array_path is not None:
    filter.MaskCellArrayPath = mask_cell_array_path
  filter.execute()
  return filter.ErrorCode

def itkfft_normalized_correlation_image(data_container_array, moving_cell_array_path = None, required_number_of_overlapping_pixels = None, required_fraction_of_overlapping_pixels = None, observer = None) -> int:
  """Pythonic interface to ITKFFTNormalizedCorrelationImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    moving_cell_array_path (DataArrayPath): Sets the "MovingCellArrayPath" filter property
    required_number_of_overlapping_pixels (double): Sets the "RequiredNumberOfOverlappingPixels" filter property
    required_fraction_of_overlapping_pixels (double): Sets the "RequiredFractionOfOverlappingPixels" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKFFTNormalizedCorrelationImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if moving_cell_array_path is not None:
    filter.MovingCellArrayPath = moving_cell_array_path
  if required_number_of_overlapping_pixels is not None:
    filter.RequiredNumberOfOverlappingPixels = required_number_of_overlapping_pixels
  if required_fraction_of_overlapping_pixels is not None:
    filter.RequiredFractionOfOverlappingPixels = required_fraction_of_overlapping_pixels
  filter.execute()
  return filter.ErrorCode

def itk_vector_rescale_intensity_image(data_container_array, output_maximum_magnitude = None, output_type = None, observer = None) -> int:
  """Pythonic interface to ITKVectorRescaleIntensityImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    output_maximum_magnitude (double): Sets the "OutputMaximumMagnitude" filter property
    output_type (int): Sets the "OutputType" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKVectorRescaleIntensityImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_maximum_magnitude is not None:
    filter.OutputMaximumMagnitude = output_maximum_magnitude
  if output_type is not None:
    filter.OutputType = output_type
  filter.execute()
  return filter.ErrorCode

def itk_patch_based_denoising_image(data_container_array, kernel_bandwidth_sigma = None, patch_radius = None, number_of_iterations = None, number_of_sample_patches = None, sample_variance = None, noise_sigma = None, noise_model_fidelity_weight = None, always_treat_components_as_euclidean = None, kernel_bandwidth_estimation = None, kernel_bandwidth_multiplication_factor = None, kernel_bandwidth_update_frequency = None, kernel_bandwidth_fraction_pixels_for_estimation = None, noise_model = None, number_of_threads = None, observer = None) -> int:
  """Pythonic interface to ITKPatchBasedDenoisingImage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    kernel_bandwidth_sigma (double): Sets the "KernelBandwidthSigma" filter property
    patch_radius (double): Sets the "PatchRadius" filter property
    number_of_iterations (double): Sets the "NumberOfIterations" filter property
    number_of_sample_patches (double): Sets the "NumberOfSamplePatches" filter property
    sample_variance (double): Sets the "SampleVariance" filter property
    noise_sigma (double): Sets the "NoiseSigma" filter property
    noise_model_fidelity_weight (double): Sets the "NoiseModelFidelityWeight" filter property
    always_treat_components_as_euclidean (bool): Sets the "AlwaysTreatComponentsAsEuclidean" filter property
    kernel_bandwidth_estimation (bool): Sets the "KernelBandwidthEstimation" filter property
    kernel_bandwidth_multiplication_factor (double): Sets the "KernelBandwidthMultiplicationFactor" filter property
    kernel_bandwidth_update_frequency (double): Sets the "KernelBandwidthUpdateFrequency" filter property
    kernel_bandwidth_fraction_pixels_for_estimation (double): Sets the "KernelBandwidthFractionPixelsForEstimation" filter property
    noise_model (int): Sets the "NoiseModel" filter property
    number_of_threads (int): Sets the "NumberOfThreads" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = itkimageprocessing.ITKPatchBasedDenoisingImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if kernel_bandwidth_sigma is not None:
    filter.KernelBandwidthSigma = kernel_bandwidth_sigma
  if patch_radius is not None:
    filter.PatchRadius = patch_radius
  if number_of_iterations is not None:
    filter.NumberOfIterations = number_of_iterations
  if number_of_sample_patches is not None:
    filter.NumberOfSamplePatches = number_of_sample_patches
  if sample_variance is not None:
    filter.SampleVariance = sample_variance
  if noise_sigma is not None:
    filter.NoiseSigma = noise_sigma
  if noise_model_fidelity_weight is not None:
    filter.NoiseModelFidelityWeight = noise_model_fidelity_weight
  if always_treat_components_as_euclidean is not None:
    filter.AlwaysTreatComponentsAsEuclidean = always_treat_components_as_euclidean
  if kernel_bandwidth_estimation is not None:
    filter.KernelBandwidthEstimation = kernel_bandwidth_estimation
  if kernel_bandwidth_multiplication_factor is not None:
    filter.KernelBandwidthMultiplicationFactor = kernel_bandwidth_multiplication_factor
  if kernel_bandwidth_update_frequency is not None:
    filter.KernelBandwidthUpdateFrequency = kernel_bandwidth_update_frequency
  if kernel_bandwidth_fraction_pixels_for_estimation is not None:
    filter.KernelBandwidthFractionPixelsForEstimation = kernel_bandwidth_fraction_pixels_for_estimation
  if noise_model is not None:
    filter.NoiseModel = noise_model
  if number_of_threads is not None:
    filter.NumberOfThreads = number_of_threads
  filter.execute()
  return filter.ErrorCode

